@@ -78,6 +78,7 @@ class TimewebCloud(TimewebCloudBase):
         network: Optional[dict] = None,
         availability_zone: Optional[ServiceAvailabilityZone] = None,
         is_root_password_required: Optional[bool] = None,
+        project_id: Optional[int] = None,
     ):
         """Create new Cloud Server. Note:
 
@@ -120,6 +121,7 @@ class TimewebCloud(TimewebCloudBase):
                 if is_root_password_required is not None
                 else {}
             ),
+            **({"project_id": project_id} if project_id else {}),
         }
 
         return self._request("POST", f"{self.api_url}/servers", json=payload)
@@ -1157,6 +1159,14 @@ class TimewebCloud(TimewebCloudBase):
         force_https: bool = False,
         backend_keepalive: bool = False,
         network: Optional[dict] = None,
+        comment: Optional[str] = None,
+        project_id: Optional[int] = None,
+        certificates: Optional[dict] = None,
+        max_connections: Optional[int] = None,
+        connect_timeout: Optional[int] = None,
+        client_timeout: Optional[int] = None,
+        server_timeout: Optional[int] = None,
+        http_timeout: Optional[int] = None,
     ):
         """Create load balancer."""
         payload = {
@@ -1175,6 +1185,34 @@ class TimewebCloud(TimewebCloudBase):
             "is_ssl": force_https,
             "is_keepalive": backend_keepalive,
             **({"network": network} if network else {}),
+            **({"comment": comment} if comment else {}),
+            **({"project_id": project_id} if project_id else {}),
+            **({"certificates": certificates} if certificates else {}),
+            **(
+                {"maxconn": max_connections}
+                if max_connections is not None
+                else {}
+            ),
+            **(
+                {"connect_timeout": connect_timeout}
+                if connect_timeout is not None
+                else {}
+            ),
+            **(
+                {"client_timeout": client_timeout}
+                if client_timeout is not None
+                else {}
+            ),
+            **(
+                {"server_timeout": server_timeout}
+                if server_timeout is not None
+                else {}
+            ),
+            **(
+                {"httprequest_timeout": http_timeout}
+                if http_timeout is not None
+                else {}
+            ),
         }
         return self._request("POST", f"{self.api_url}/balancers", json=payload)
 
@@ -1195,6 +1233,11 @@ class TimewebCloud(TimewebCloudBase):
         proxy_protocol: Optional[bool] = None,
         force_https: Optional[bool] = None,
         backend_keepalive: Optional[bool] = None,
+        max_connections: Optional[int] = None,
+        connect_timeout: Optional[int] = None,
+        client_timeout: Optional[int] = None,
+        server_timeout: Optional[int] = None,
+        http_timeout: Optional[int] = None,
     ):
         """Update load balancer settings."""
         payload = {
@@ -1220,6 +1263,31 @@ class TimewebCloud(TimewebCloudBase):
                 if backend_keepalive is not None
                 else {}
             ),
+            **(
+                {"maxconn": max_connections}
+                if max_connections is not None
+                else {}
+            ),
+            **(
+                {"connect_timeout": connect_timeout}
+                if connect_timeout is not None
+                else {}
+            ),
+            **(
+                {"client_timeout": client_timeout}
+                if client_timeout is not None
+                else {}
+            ),
+            **(
+                {"server_timeout": server_timeout}
+                if server_timeout is not None
+                else {}
+            ),
+            **(
+                {"httprequest_timeout": http_timeout}
+                if http_timeout is not None
+                else {}
+            ),
         }
         return self._request(
             "PATCH", f"{self.api_url}/balancers/{balancer_id}", json=payload
